==> dhall-bash-1.0.41-23-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-bash
version:              1.0.41
visibility:           public
id:                   dhall-bash-1.0.41-FHml97ZEuleLAFPWgfWsmA
key:                  dhall-bash-1.0.41-FHml97ZEuleLAFPWgfWsmA
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  2eb23dfe0b3277065f364083ed2f89c0
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.41-FHml97ZEuleLAFPWgfWsmA
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.1-DkMx8Nr4uBcCdN2pZl7J7j
    neat-interpolation-0.5.1.4-C6TcVYqLbVD8NpeK6cJh8y
    shell-escape-0.2.0-4QCIbKwyBttCLkZmHxRmPt text-2.0.2

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-bash-1.0.41-24-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-bash
version:              1.0.41
visibility:           public
id:                   dhall-bash-1.0.41-DfR5mKxIpg0Cc1cjZQsYYe
key:                  dhall-bash-1.0.41-DfR5mKxIpg0Cc1cjZQsYYe
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  3099f486ffb33696a0fef90b14e3ed7d
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-bash-1.0.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.41-DfR5mKxIpg0Cc1cjZQsYYe
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.1-GYPRq5sog4XHS9lOxTFhYI
    neat-interpolation-0.5.1.4-C6TcVYqLbVD8NpeK6cJh8y
    shell-escape-0.2.0-4QCIbKwyBttCLkZmHxRmPt text-2.0.2

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
